@@ -18,7 +18,7 @@ import pango
 from gobject import markup_escape_text
 from accerciser.plugin import ViewportPlugin
 from accerciser.icons import getIcon
-from accerciser.i18n import _, N_
+from accerciser.i18n import _, N_, DOMAIN
 from xml.dom import minidom
 
 UI_FILE = os.path.join(os.path.dirname(__file__), 
@@ -51,6 +51,7 @@ class InterfaceViewer(ViewportPlugin):
     del dom
 
     ui_xml = gtk.Builder()
+    ui_xml.set_translation_domain(DOMAIN)
     ui_xml.add_from_file(UI_FILE)
     frame = ui_xml.get_object('iface_view_frame')
     self.label_role = ui_xml.get_object('label_role')
@@ -80,11 +81,13 @@ class InterfaceViewer(ViewportPlugin):
     ui_xml.connect_signals(self)    
 
     # Mark all expanders with no associated section classes as unimplemented
-    implemented_sections = [obj.interface_name.lower() for obj in self.sections]
+    implemented_expanders = [s.expander for s in self.sections]
     vbox_ifaces = ui_xml.get_object('vbox_ifaces')
+
     for expander in vbox_ifaces.get_children():
-      iface_name = expander.name.replace('expander_', '')
-      if iface_name not in implemented_sections:
+      if expander not in implemented_expanders:
+        iface_name = \
+          expander.get_label().lower().replace(' ', '').replace('_', '')
         section = _InterfaceSection(ui_xml, self.node, iface_name)
         section.disable()
 
