@@ -92,9 +92,11 @@ class Node(gobject.GObject, Tools):
       if isinstance(i, pyatspi.Accessibility.Component):
         self.extents = i.getExtents(pyatspi.DESKTOP_COORDS)
     self.tree_path = None
-    self.highlight()
-    self.emit('accessible-changed', acc)
-  
+    if acc != self.desktop:
+        # Don't highlight the entire desktop, it gets annoying.
+        self.highlight()
+    self.emit('accessible-changed', acc)  
+
   def updateToPath(self, app_name, path):
     '''
     Update the node with a new accessible by providing a tree path 
@@ -180,14 +182,17 @@ class _HighLight(gtk.Window):
   Highlight box class. Uses compositing when available. When not, it does
   transparency client-side.
   '''
-  _svg = r"""
-<svg width="100%" height="100%" version="1.1"
-  xmlns="http://www.w3.org/2000/svg">
-  <rect x="$x" y="$y" width="$width" height="$height"
-      style="fill:$fill;stroke-width:$stroke_width;stroke:$stroke;
-      fill-opacity:$fill_opacity;stroke-opacity:$stroke_opacity"
-      rx="2" ry="2"
-      />
+  _svg = """<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<svg xmlns="http://www.w3.org/2000/svg"> 
+  <rect
+       style="fill:$fill;fill-opacity:$fill_opacity;fill-rule:evenodd;stroke:$stroke;stroke-width:2;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:$stroke_opacity"
+       id="highlight"
+       width="$width"
+       height="$height"
+       x="$x"
+       y="$y"
+       rx="2"
+       ry="2" />
 </svg>
 """
   def __init__(self, x, y, w, h, 
@@ -237,12 +242,13 @@ class _HighLight(gtk.Window):
     # Connect "expose" event.
     self.connect("expose-event", self._onExpose)
     
-  def highlight(self, duration=0):
+  def highlight(self, duration=500):
     if duration > 0:
       gobject.timeout_add(duration, lambda w: w.destroy(), self)
-    self.show_all()
+      self.show_all()
+    else:
+      self.destroy()
     
-
   def _onExpose(self, widget, event):
     svgh = rsvg.Handle()
     try:
@@ -270,3 +276,10 @@ class _HighLight(gtk.Window):
 
     svgh.render_cairo( cr )
     del svgh
+
+if __name__ == "__main__":
+    hl = _HighLight(200, 200, 200, 200, '#ff0000', 
+                    0.5, '#ff0000', 0.996108949416, 8.0, 0)
+    hl.highlight(2000)
+    gtk.main()
+
