@@ -12,15 +12,15 @@ is available at U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import gtk
-from i18n import _, N_
+from i18n import _, N_, C_
 
 menu_actions = gtk.ActionGroup('MenuActions')
 
 menu_actions.add_actions([
     ('File', None, _('_File')),
     ('Edit', None, _('_Edit')),
-    ('Bookmarks', None, _('_Bookmarks')),
-    ('View', None, _('_View')),
+    ('Bookmarks', None, C_('menu', '_Bookmarks')),
+    ('View', None, C_('menu', '_View')),
     ('Help', None, _('_Help'))])
 
 ui_xml = '''
